changeset 30521:acdee7461c9f

merged from im.pidgin.pidgin
author Yoshiki Yazawa <yaz@honeyplanet.jp>
date Thu, 27 May 2010 09:58:53 +0900
parents 85d6355daa8f (current diff) 51c31805d2a7 (diff)
children 3ed54142386f
files
diffstat 7 files changed, 270 insertions(+), 169 deletions(-) [+]
line wrap: on
line diff
--- a/libpurple/media/backend-fs2.h	Thu May 27 07:50:06 2010 +0900
+++ b/libpurple/media/backend-fs2.h	Thu May 27 09:58:53 2010 +0900
@@ -55,6 +55,7 @@
  */
 GType purple_media_backend_fs2_get_type(void);
 
+#ifdef USE_GSTREAMER
 /*
  * Temporary function in order to be able to test while
  * integrating with PurpleMedia
@@ -71,6 +72,7 @@
 void purple_media_backend_fs2_set_output_volume(PurpleMediaBackendFs2 *self,
 		const gchar *sess_id, const gchar *who, double level);
 /* end tmp */
+#endif /* USE_GSTREAMER */
 
 G_END_DECLS
 
--- a/pidgin/gtkdocklet-gtk.c	Thu May 27 07:50:06 2010 +0900
+++ b/pidgin/gtkdocklet-gtk.c	Thu May 27 09:58:53 2010 +0900
@@ -38,7 +38,13 @@
 static void
 docklet_gtk_status_clicked_cb(GtkStatusIcon *status_icon, guint button, guint activate_time, gpointer user_data)
 {
-	pidgin_docklet_clicked(button); 
+	purple_debug_info("docklet", "The button is %u\n", button);
+#ifdef GDK_WINDOWING_QUARTZ
+	/* You can only click left mouse button on MacOSX native GTK. Let that be the menu */
+	pidgin_docklet_clicked(3);
+#else
+	pidgin_docklet_clicked(button);
+#endif
 }
 
 static void
--- a/pidgin/pixmaps/Makefile.am	Thu May 27 07:50:06 2010 +0900
+++ b/pidgin/pixmaps/Makefile.am	Thu May 27 09:58:53 2010 +0900
@@ -482,6 +482,8 @@
 		tray/16/message_4bit.ico \
 		tray/16/offline_4bit.ico
 
+TRAY_THEME =	tray/hicolor/index.theme
+
 TRAY_16 = \
 		tray/hicolor/16x16/status/pidgin-tray-away.png \
 		tray/hicolor/16x16/status/pidgin-tray-busy.png \
@@ -584,6 +586,7 @@
 		$(TOOLBAR_22) \
 		$(TOOLBAR_32) \
 		$(TOOLBAR_48) \
+		$(TRAY_THEME) \
 		$(TRAY_16) \
 		$(TRAY_16_ICO) \
 		$(TRAY_22) \
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/pidgin/pixmaps/tray/hicolor/index.theme	Thu May 27 09:58:53 2010 +0900
@@ -0,0 +1,33 @@
+[Icon Theme]
+Name=Pidgin
+Comment=Icon theme for Pidgin tray icons
+Hidden=True
+Directories=16x16/status,22x22/status,32x32/status,48x48/status,scalable/status
+
+[16x16/status]
+Size=16
+Context=Status
+Type=Threshold
+
+[22x22/status]
+Size=22
+Context=Status
+Type=Threshold
+
+[32x32/status]
+Size=32
+Context=Status
+Type=Threshold
+
+[48x48/status]
+Size=48
+Context=Status
+Type=Threshold
+
+[scalable/status]
+MinSize=1
+Size=128
+MaxSize=256
+Context=Status
+Type=Scalable
+
--- a/po/ca.po	Thu May 27 07:50:06 2010 +0900
+++ b/po/ca.po	Thu May 27 09:58:53 2010 +0900
@@ -33,8 +33,8 @@
 msgstr ""
 "Project-Id-Version: Pidgin\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-17 23:18-0400\n"
-"PO-Revision-Date: 2010-05-11 22:10+0200\n"
+"POT-Creation-Date: 2010-05-25 21:38+0200\n"
+"PO-Revision-Date: 2010-05-25 21:51+0200\n"
 "Last-Translator: Josep Puigdemont i Casamajó <josep.puigdemont@gmail.com>\n"
 "Language-Team: Catalan <tradgnome@softcatala.net>\n"
 "MIME-Version: 1.0\n"
@@ -1385,6 +1385,7 @@
 msgid "Saved Statuses"
 msgstr "Estats desats"
 
+#. title
 msgid "Title"
 msgstr "Títol"
 
@@ -1947,7 +1948,6 @@
 msgid "Thread creation failure: %s"
 msgstr "S'ha produït un error en crear un fil: %s"
 
-#. Data is assumed to be the destination bn
 msgid "Unknown reason"
 msgstr "Motiu desconegut"
 
@@ -3223,6 +3223,9 @@
 msgstr "UIN"
 
 #. first name
+#. purple_notify_user_info_add_pair( info, _( "Hidden Number" ), profile->hidden ? _( "Yes" ) : _( "No" ) );
+#. optional information
+#. purple_notify_user_info_add_pair( info, _( "Title" ), profile->title );
 msgid "First Name"
 msgstr "Nom"
 
@@ -3967,6 +3970,7 @@
 msgid "Postal Code"
 msgstr "Codi postal"
 
+#. purple_notify_user_info_add_pair( info, _( "Email" ), profile->email );
 msgid "Country"
 msgstr "País"
 
@@ -3981,8 +3985,6 @@
 msgid "Organization Unit"
 msgstr "Secció de l'organització"
 
-#. title
-#. optional information
 msgid "Job Title"
 msgstr "Títol de la feina"
 
@@ -5736,6 +5738,9 @@
 msgid "Show custom smileys"
 msgstr "Mostra emoticones personalitzades"
 
+msgid "Allow direct connections"
+msgstr "Permet connexions directes"
+
 msgid "nudge: nudge a user to get their attention"
 msgstr "nudge: doneu un cop de colze a un usuari perquè us pari atenció"
 
@@ -5976,6 +5981,9 @@
 "Encara no s'ha pogut recuperar la informació del vostre perfil. Torneu-ho a "
 "intentar més tard."
 
+msgid "Your MXitId"
+msgstr "El vostre MXitID"
+
 #. pin
 msgid "PIN"
 msgstr "PIN"
@@ -6127,7 +6135,11 @@
 msgid "Status Message"
 msgstr "Missatge d'estat"
 
+msgid "Rejection Message"
+msgstr "Missatge de rebuig"
+
 # Segons la viquipèdia
+#. hidden number
 msgid "Hidden Number"
 msgstr "Nombre ocult"
 
@@ -6934,6 +6946,63 @@
 msgid "Invalid chat room name"
 msgstr "El nom de sala de xat no és vàlid"
 
+msgid "Invalid error"
+msgstr "Error invàlid"
+
+msgid "Cannot receive IM due to parental controls"
+msgstr "Els controls parentals no permeten que es pugui rebre MI"
+
+msgid "Cannot send SMS without accepting terms"
+msgstr "No es poden enviar SMS si no s'accepten els termes"
+
+msgid "Cannot send SMS"
+msgstr "No s'ha pogut enviar l'SMS"
+
+#. SMS_WITHOUT_DISCLAIMER is weird
+msgid "Cannot send SMS to this country"
+msgstr "No es poden enviar SMS a aquest país"
+
+#. Undocumented
+msgid "Cannot send SMS to unknown country"
+msgstr "No es poden enviar SMS a un país desconegut"
+
+msgid "Bot accounts cannot initiate IMs"
+msgstr "Els robots no poden iniciar MI"
+
+msgid "Bot account cannot IM this user"
+msgstr "Aquest robot no pot fer MI amb aquest usuari"
+
+msgid "Bot account reached IM limit"
+msgstr "Aquest robot ha superat el límit de MI"
+
+msgid "Bot account reached daily IM limit"
+msgstr "Aquest robot ha superat el límit de MI diari"
+
+msgid "Bot account reached monthly IM limit"
+msgstr "Aquest robot ha superat el límit de MI mensual"
+
+msgid "Unable to receive offline messages"
+msgstr "No s'han pogut rebre els missatges fora de línia"
+
+msgid "Offline message store full"
+msgstr "El dipòsit per a missatge de fora de línia és ple"
+
+#, c-format
+msgid "Unable to send message: %s (%s)"
+msgstr "No s'ha pogut enviar el missatge: %s (%s)"
+
+#, c-format
+msgid "Unable to send message: %s"
+msgstr "No s'ha pogut enviar el missatge: %s"
+
+#, c-format
+msgid "Unable to send message to %s: %s (%s)"
+msgstr "No s'ha pogut enviar el missatge a %s: %s (%s)"
+
+#, c-format
+msgid "Unable to send message to %s: %s"
+msgstr "No s'ha pogut enviar el missatge a %s: %s"
+
 msgid "Thinking"
 msgstr "Pensant"
 
@@ -7087,116 +7156,6 @@
 msgid "File %s is %s, which is larger than the maximum size of %s."
 msgstr "El fitxer %s és %s, que és més gran que la mida màxima de %s."
 
-msgid "Invalid error"
-msgstr "Error invàlid"
-
-msgid "Invalid SNAC"
-msgstr "SNAC invàlid"
-
-msgid "Rate to host"
-msgstr "Velocitat cap a l'ordinador"
-
-msgid "Rate to client"
-msgstr "Velocitat cap al client"
-
-msgid "Service unavailable"
-msgstr "Servei no disponible"
-
-msgid "Service not defined"
-msgstr "Servei no definit"
-
-msgid "Obsolete SNAC"
-msgstr "SNAC obsolet"
-
-msgid "Not supported by host"
-msgstr "El servidor no ho permet"
-
-msgid "Not supported by client"
-msgstr "El client no ho permet"
-
-msgid "Refused by client"
-msgstr "Rebutjat pel client"
-
-msgid "Reply too big"
-msgstr "Resposta massa gran"
-
-msgid "Responses lost"
-msgstr "S'han perdut respostes"
-
-msgid "Request denied"
-msgstr "Petició denegada"
-
-msgid "Busted SNAC payload"
-msgstr "Càrrega SNAC malmesa"
-
-msgid "Insufficient rights"
-msgstr "Drets insuficients"
-
-msgid "In local permit/deny"
-msgstr "En la llista de permès/denegat local"
-
-msgid "Warning level too high (sender)"
-msgstr "Nivell d'avís massa alt (remitent)"
-
-msgid "Warning level too high (receiver)"
-msgstr "Nivell d'avís massa alt (receptor)"
-
-msgid "User temporarily unavailable"
-msgstr "Usuari no disponible temporalment"
-
-msgid "No match"
-msgstr "Cap coincidència"
-
-msgid "List overflow"
-msgstr "Sobreeiximent de la llista"
-
-msgid "Request ambiguous"
-msgstr "Petició ambigua"
-
-msgid "Queue full"
-msgstr "Cua plena"
-
-msgid "Not while on AOL"
-msgstr "No es pot fer mentre estigui a AOL"
-
-msgid "Cannot receive IM due to parental controls"
-msgstr "Els controls parentals no permeten que es pugui rebre MI"
-
-msgid "Cannot send SMS without accepting terms"
-msgstr "No es poden enviar SMS si no s'accepten els termes"
-
-msgid "Cannot send SMS"
-msgstr "No s'ha pogut enviar l'SMS"
-
-#. SMS_WITHOUT_DISCLAIMER is weird
-msgid "Cannot send SMS to this country"
-msgstr "No es poden enviar SMS a aquest país"
-
-#. Undocumented
-msgid "Cannot send SMS to unknown country"
-msgstr "No es poden enviar SMS a un país desconegut"
-
-msgid "Bot accounts cannot initiate IMs"
-msgstr "Els robots no poden iniciar MI"
-
-msgid "Bot account cannot IM this user"
-msgstr "Aquest robot no pot fer MI amb aquest usuari"
-
-msgid "Bot account reached IM limit"
-msgstr "Aquest robot ha superat el límit de MI"
-
-msgid "Bot account reached daily IM limit"
-msgstr "Aquest robot ha superat el límit de MI diari"
-
-msgid "Bot account reached monthly IM limit"
-msgstr "Aquest robot ha superat el límit de MI mensual"
-
-msgid "Unable to receive offline messages"
-msgstr "No s'han pogut rebre els missatges fora de línia"
-
-msgid "Offline message store full"
-msgstr "El dipòsit per a missatge de fora de línia és ple"
-
 msgid ""
 "(There was an error receiving this message.  The buddy you are speaking with "
 "is probably using a different encoding than expected.  If you know what "
@@ -7548,28 +7507,9 @@
 msgstr[1] "Heu perdut %hu missatges de %s per motius desconeguts."
 
 #, c-format
-msgid "Unable to send message: %s (%s)"
-msgstr "No s'ha pogut enviar el missatge: %s (%s)"
-
-#, c-format
-msgid "Unable to send message: %s"
-msgstr "No s'ha pogut enviar el missatge: %s"
-
-#, c-format
-msgid "Unable to send message to %s: %s (%s)"
-msgstr "No s'ha pogut enviar el missatge a %s: %s (%s)"
-
-#, c-format
-msgid "Unable to send message to %s: %s"
-msgstr "No s'ha pogut enviar el missatge a %s: %s"
-
-#, c-format
 msgid "User information not available: %s"
 msgstr "La informació de l'usuari no està disponible: %s"
 
-msgid "Unknown reason."
-msgstr "Motiu desconegut."
-
 msgid "Online Since"
 msgstr "En línia des de"
 
@@ -15302,6 +15242,7 @@
 msgid "This plugin is useful for debugging XMPP servers or clients."
 msgstr "Aquest connector és útil per a depurar servidors o clients XMPP."
 
+#. $(^Name) is the current Version name (e.g. Pidgin 2.7.0).  $_CLICK will become a translated version of "Click Next to continue."
 msgid ""
 "$(^Name) is released under the GNU General Public License (GPL). The license "
 "is provided here for information purposes only. $_CLICK"
@@ -15309,6 +15250,7 @@
 "$(^Name) és distribuït sota llicència GPL. Podeu consultar la llicència, "
 "només per proposits informatius, aquí.  $_CLICK"
 
+#. Installer Subsection Detailed Description
 msgid "A multi-platform GUI toolkit, used by Pidgin"
 msgstr "Una eina IGU multiplataforma, utilitzada per Pidgin"
 
@@ -15319,75 +15261,99 @@
 "Hi ha una instància del Pidgin executant-se. Surt del Pidgin i torna a "
 "intentar-ho."
 
+#. Installer Subsection Detailed Description
 msgid "Core Pidgin files and dlls"
 msgstr "Fitxers i dlls del nucli de Pidgin"
 
+#. Installer Subsection Detailed Description
 msgid "Create a Start Menu entry for Pidgin"
 msgstr "Crear una entrada Pidgin al Menu Inici"
 
+#. Installer Subsection Detailed Description
 msgid "Create a shortcut to Pidgin on the Desktop"
 msgstr "Afegir un enllaç directe al Pidgin a l'Escriptori"
 
+#. Installer Subsection Text
 msgid "Debug Symbols (for reporting crashes)"
-msgstr ""
-
+msgstr "Símbols de depuració (per informar d'errades)"
+
+#. Installer Subsection Text
 msgid "Desktop"
 msgstr "Escriptori"
 
+#. $R2 will display the URL that the GTK+ Runtime failed to download from
 msgid ""
 "Error Downloading the GTK+ Runtime ($R2).$\\rThis is required for Pidgin to "
 "function; if retrying fails, you may need to use the 'Offline Installer' "
 "from http://pidgin.im/download/windows/ ."
 msgstr ""
-
+"S'ha produït un error en baixar l'entorn d'execució GTK+ ($R2).$\\rEl Pidgin "
+"requereix aquest entorn per a poder-se executar. Si ho torneu a provar i no "
+"funciona, haureu de fer servir l'instal·lador «fora de línia» de http://"
+"pidgin.im/download/windows/ ."
+
+#. $R2 will display the URL that the Debug Symbols failed to download from
 msgid ""
 "Error Installing Debug Symbols ($R2).$\\rIf retrying fails, you may need to "
 "use the 'Offline Installer' from http://pidgin.im/download/windows/ ."
 msgstr ""
-
+"S'ha produït un error en instal·lar els símbols de depuració ($R2).$\\rSi "
+"falla en reintentar-ho, haureu de fer servir l'instal·lador «fora de línia» "
+"de http://pidgin.im/download/windows/ ."
+
+#. $R3 will display the URL that the Dictionary failed to download from
 #, no-c-format
 msgid ""
 "Error Installing Spellchecking ($R3).$\\rIf retrying fails, manual "
 "installation instructions are at: http://developer.pidgin.im/wiki/Installing%"
 "20Pidgin#manual_win32_spellcheck_installation"
 msgstr ""
-
-#, fuzzy
+"S'ha produït un error en instal·lar el corrector ortogràfic ($R3).$\\rSi "
+"falla en reintentar-ho, podeu seguir les instruccions d'instal·lació manual "
+"d'aquí: http://developer.pidgin.im/wiki/Installing%"
+"20Pidgin#manual_win32_spellcheck_installation"
+
+#. Installer Subsection Text
 msgid "GTK+ Runtime (required if not present)"
-msgstr "Entorn d'Execució GTK+ (necessari)"
-
-#, fuzzy
+msgstr "Entorn d'Execució GTK+ (necessari si no està instal·lat)"
+
+#. Installer Subsection Text
 msgid "Localizations"
-msgstr "Ubicació"
-
-#. License Page
+msgstr "Localitzacions"
+
+#. "Next >" appears on a button on the License Page of the Installer
 msgid "Next >"
 msgstr "Següent >"
 
-#. Components Page
+#. Installer Subsection Text
 msgid "Pidgin Instant Messaging Client (required)"
 msgstr "Client Pidgin de Missatgeria Instantània (necessari)"
 
-#. GTK+ Section Prompts
 msgid ""
 "Pidgin requires a compatible GTK+ Runtime (which doesn't appear to be "
 "already present).$\\rAre you sure you want to skip installing the GTK+ "
 "Runtime?"
 msgstr ""
-
+"El Pidgin requereix un entorn d'execució GTK+ compatible (que no sembla que "
+"tingueu instal·lat).$\\rEsteu segur que en voleu ometre la instal·lació?"
+
+#. Installer Subsection Text
 msgid "Shortcuts"
 msgstr "Enllaços directes"
 
+#. Installer Subsection Detailed Description
 msgid "Shortcuts for starting Pidgin"
 msgstr "Enllaços directes per iniciar el Pidgin"
 
-#. Spellcheck Section Prompts
+#. Installer Subsection Text
 msgid "Spellchecking Support"
 msgstr "Suport a la Verificació de l'Ortografia "
 
+#. Installer Subsection Text
 msgid "Start Menu"
 msgstr "Menu Inici"
 
+#. Installer Subsection Detailed Description
 msgid ""
 "Support for Spellchecking.  (Internet connection required for installation)"
 msgstr ""
@@ -15397,7 +15363,6 @@
 msgid "The installer is already running."
 msgstr "L'instal.lador encara està executant-se."
 
-#. Uninstall Section Prompts
 msgid ""
 "The uninstaller could not find registry entries for Pidgin.$\\rIt is likely "
 "that another user installed this application."
@@ -15405,23 +15370,96 @@
 "L'instal.lador podria no trobar les entrades del registre de Pidgin.$"
 "\\rProbablement un altre usuari ha instal.lat aquesta aplicació."
 
-#. URL Handler section
+#. Installer Subsection Text
 msgid "URI Handlers"
-msgstr ""
-
-#. Pidgin Section Prompts and Texts
+msgstr "Gestors d'URI"
+
 msgid ""
 "Unable to uninstall the currently installed version of Pidgin. The new "
 "version will be installed without removing the currently installed version."
 msgstr ""
-
-#. Installer Finish Page
+"No s'ha pogut desinstal·lar la versió actual del Pidgin. La nova versió "
+"s'instal·larà sense suprimir-ne la que hi ha actualment instal·lada."
+
+#. Text displayed on Installer Finish Page
 msgid "Visit the Pidgin Web Page"
 msgstr "Visita la pàgina web de Pidgin per Windows"
 
 msgid "You do not have permission to uninstall this application."
 msgstr "No tens permís per desinstal.lar aquesta aplicació."
 
+#~ msgid "Invalid SNAC"
+#~ msgstr "SNAC invàlid"
+
+#~ msgid "Rate to host"
+#~ msgstr "Velocitat cap a l'ordinador"
+
+#~ msgid "Rate to client"
+#~ msgstr "Velocitat cap al client"
+
+#~ msgid "Service unavailable"
+#~ msgstr "Servei no disponible"
+
+#~ msgid "Service not defined"
+#~ msgstr "Servei no definit"
+
+#~ msgid "Obsolete SNAC"
+#~ msgstr "SNAC obsolet"
+
+#~ msgid "Not supported by host"
+#~ msgstr "El servidor no ho permet"
+
+#~ msgid "Not supported by client"
+#~ msgstr "El client no ho permet"
+
+#~ msgid "Refused by client"
+#~ msgstr "Rebutjat pel client"
+
+#~ msgid "Reply too big"
+#~ msgstr "Resposta massa gran"
+
+#~ msgid "Responses lost"
+#~ msgstr "S'han perdut respostes"
+
+#~ msgid "Request denied"
+#~ msgstr "Petició denegada"
+
+#~ msgid "Busted SNAC payload"
+#~ msgstr "Càrrega SNAC malmesa"
+
+#~ msgid "Insufficient rights"
+#~ msgstr "Drets insuficients"
+
+#~ msgid "In local permit/deny"
+#~ msgstr "En la llista de permès/denegat local"
+
+#~ msgid "Warning level too high (sender)"
+#~ msgstr "Nivell d'avís massa alt (remitent)"
+
+#~ msgid "Warning level too high (receiver)"
+#~ msgstr "Nivell d'avís massa alt (receptor)"
+
+#~ msgid "User temporarily unavailable"
+#~ msgstr "Usuari no disponible temporalment"
+
+#~ msgid "No match"
+#~ msgstr "Cap coincidència"
+
+#~ msgid "List overflow"
+#~ msgstr "Sobreeiximent de la llista"
+
+#~ msgid "Request ambiguous"
+#~ msgstr "Petició ambigua"
+
+#~ msgid "Queue full"
+#~ msgstr "Cua plena"
+
+#~ msgid "Not while on AOL"
+#~ msgstr "No es pot fer mentre estigui a AOL"
+
+#~ msgid "Unknown reason."
+#~ msgstr "Motiu desconegut."
+
 #~ msgid "Current Mood"
 #~ msgstr "Estat d'ànim actual"
 
--- a/po/de.po	Thu May 27 07:50:06 2010 +0900
+++ b/po/de.po	Thu May 27 09:58:53 2010 +0900
@@ -11,8 +11,8 @@
 msgstr ""
 "Project-Id-Version: de\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-20 12:11+0200\n"
-"PO-Revision-Date: 2010-05-20 12:08+0200\n"
+"POT-Creation-Date: 2010-05-26 10:42+0200\n"
+"PO-Revision-Date: 2010-05-26 10:42+0200\n"
 "Last-Translator: Björn Voigt <bjoern@cs.tu-berlin.de>\n"
 "Language-Team: Deutsch <de@li.org>\n"
 "MIME-Version: 1.0\n"
@@ -1360,6 +1360,7 @@
 msgid "Saved Statuses"
 msgstr "Gespeicherter Status"
 
+#. title
 msgid "Title"
 msgstr "Titel"
 
@@ -3205,6 +3206,9 @@
 msgstr "UIN"
 
 #. first name
+#. purple_notify_user_info_add_pair( info, _( "Hidden Number" ), profile->hidden ? _( "Yes" ) : _( "No" ) );
+#. optional information
+#. purple_notify_user_info_add_pair( info, _( "Title" ), profile->title );
 msgid "First Name"
 msgstr "Vorname"
 
@@ -3957,6 +3961,7 @@
 msgid "Postal Code"
 msgstr "Postleitzahl"
 
+#. purple_notify_user_info_add_pair( info, _( "Email" ), profile->email );
 msgid "Country"
 msgstr "Land"
 
@@ -3971,8 +3976,6 @@
 msgid "Organization Unit"
 msgstr "Organisationseinheit"
 
-#. title
-#. optional information
 msgid "Job Title"
 msgstr "Beruf"
 
@@ -5736,6 +5739,9 @@
 msgid "Show custom smileys"
 msgstr "Zeige benutzerdefinierte Smileys"
 
+msgid "Allow direct connections"
+msgstr "Erlaube direkte Verbindungen"
+
 msgid "nudge: nudge a user to get their attention"
 msgstr "nudge: Einen Kontakt anstoßen, um seine Aufmerksamkeit zu erhalten"
 
@@ -5982,6 +5988,9 @@
 "Ihre Profil-Informationen wurden noch nicht abgerufen. Bitte versuchen Sie "
 "es später noch einmal."
 
+msgid "Your MXitId"
+msgstr "Ihre MXit-ID"
+
 #. pin
 msgid "PIN"
 msgstr "PIN"
@@ -6141,6 +6150,10 @@
 msgid "Status Message"
 msgstr "Status-Nachricht"
 
+msgid "Rejection Message"
+msgstr "Ablehnungsnachricht"
+
+#. hidden number
 msgid "Hidden Number"
 msgstr "Versteckte Nummer"
 
@@ -15277,6 +15290,10 @@
 "$(^Name) wird unter der GNU General Public License (GPL) veröffentlicht. Die "
 "Lizenz dient hier nur der Information. $_CLICK"
 
+#. Installer Subsection Detailed Description
+msgid "A multi-platform GUI toolkit, used by Pidgin"
+msgstr "Ein Multi-Plattform-GUI-Toolkit, verwendet von Pidgin"
+
 msgid ""
 "An instance of Pidgin is currently running.  Please exit Pidgin and try "
 "again."
@@ -15486,9 +15503,6 @@
 #~ msgid "Unknown reason."
 #~ msgstr "Unbekannter Grund."
 
-#~ msgid "A multi-platform GUI toolkit, used by Pidgin"
-#~ msgstr "Ein Multi-Plattform-GUI-Toolkit, verwendet von Pidgin"
-
 #~ msgid "Current Mood"
 #~ msgstr "Momentane Stimmung"
--- a/libpurple/protocols/mxit/login.c	Thu May 27 07:50:06 2010 +0900
+++ b/libpurple/protocols/mxit/login.c	Thu May 27 09:58:53 2010 +0900
@@ -333,13 +333,15 @@
 	purple_request_field_string_set_editable( field, FALSE );
 	purple_request_field_group_add_field( group, field );
 
-	/* nick name */
+	/* nick name (required) */
 	field = purple_request_field_string_new( "nickname", _( "Nick Name" ), profile->nickname, FALSE );
+	purple_request_field_set_required( field, TRUE );
 	purple_request_field_group_add_field( group, field );
 
-	/* birthday */
+	/* birthday (required) */
 	field = purple_request_field_string_new( "bday", _( "Birthday" ), profile->birthday, FALSE );
 	purple_request_field_string_set_default_value( field, "YYYY-MM-DD" );
+	purple_request_field_set_required( field, TRUE );
 	purple_request_field_group_add_field( group, field );
 
 	/* gender */
@@ -348,12 +350,14 @@
 	purple_request_field_choice_add( field, _( "Male" ) );			/* 1 */
 	purple_request_field_group_add_field( group, field );
 
-	/* pin */
+	/* pin (required) */
 	field = purple_request_field_string_new( "pin", _( "PIN" ), profile->pin, FALSE );
 	purple_request_field_string_set_masked( field, TRUE );
+	purple_request_field_set_required( field, TRUE );
 	purple_request_field_group_add_field( group, field );
 	field = purple_request_field_string_new( "pin2", _( "Verify PIN" ), "", FALSE );
 	purple_request_field_string_set_masked( field, TRUE );
+	purple_request_field_set_required( field, TRUE );
 	purple_request_field_group_add_field( group, field );
 
 	/* show the form to the user to complete */
@@ -636,8 +640,9 @@
 	field = purple_request_field_image_new( "capcha", _( "Security Code" ), (gchar*) logindata->captcha, logindata->captcha_size );
 	purple_request_field_group_add_field( group, field );
 
 	/* ask for input */
 	field = purple_request_field_string_new( "code", _( "Enter Security Code" ), NULL, FALSE );
+	purple_request_field_set_required( field, TRUE );
 	purple_request_field_group_add_field( group, field );
 
 	/* choose your country, but be careful, we already know your IP! ;-) */
@@ -636,8 +640,9 @@
 	purple_request_field_group_add_field( group, field );
 
-	/* ask for input */
+	/* ask for input (required) */
 	field = purple_request_field_string_new( "code", _( "Enter Security Code" ), NULL, FALSE );